#[non_exhaustive]pub struct ElementRef {
pub table: String,
pub row: usize,
pub source_uid: Option<String>,
}Expand description
A row in one table of the static payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table: StringPayload table name, such as loads, generators, branches, or hvdc.
row: usizeZero based row index in table.
source_uid: Option<String>Optional source record UID for diagnostics and provenance.
Implementations