pub struct DerivedMetadata {
pub matrix_stats: Option<Value>,
pub normalized_solver_tables: Option<NormalizedSolverTableMetadata>,
pub cache_keys: BTreeMap<String, String>,
}Expand description
Optional derived metadata: matrix statistics, solver table metadata, and cache keys. Empty by default; the scaffold never populates it.
Fields
matrix_stats: Option<Value>normalized_solver_tables: Option<NormalizedSolverTableMetadata>cache_keys: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for DerivedMetadata
impl Clone for DerivedMetadata
Sourcefn clone(&self) -> DerivedMetadata
fn clone(&self) -> DerivedMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DerivedMetadata
impl Debug for DerivedMetadata
Sourceimpl Default for DerivedMetadata
impl Default for DerivedMetadata
Sourcefn default() -> DerivedMetadata
fn default() -> DerivedMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DerivedMetadata
impl<'de> Deserialize<'de> for DerivedMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DerivedMetadata
impl JsonSchema for DerivedMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DerivedMetadata
impl PartialEq for DerivedMetadata
Sourceimpl Serialize for DerivedMetadata
impl Serialize for DerivedMetadata
impl StructuralPartialEq for DerivedMetadata