pub struct SourceMapEntry {
pub element_path: String,
pub source_ref: SourceRef,
pub mapping_kind: MappingKind,
pub confidence: Confidence,
}Expand description
One element_path -> source mapping.
Fields
element_path: StringJSON pointer (or best-effort locator) into the package payload.
source_ref: SourceRefmapping_kind: MappingKindconfidence: ConfidenceTrait Implementations
Sourceimpl Clone for SourceMapEntry
impl Clone for SourceMapEntry
Sourcefn clone(&self) -> SourceMapEntry
fn clone(&self) -> SourceMapEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceMapEntry
impl Debug for SourceMapEntry
Sourceimpl<'de> Deserialize<'de> for SourceMapEntry
impl<'de> Deserialize<'de> for SourceMapEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SourceMapEntry
Sourceimpl JsonSchema for SourceMapEntry
impl JsonSchema for SourceMapEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SourceMapEntry
impl PartialEq for SourceMapEntry
Sourceimpl Serialize for SourceMapEntry
impl Serialize for SourceMapEntry
impl StructuralPartialEq for SourceMapEntry