#[non_exhaustive]pub struct StudyCommit {
pub label: Option<String>,
pub created_at: Option<String>,
pub edits: Vec<StudyEdit>,
pub metadata: BTreeMap<String, Value>,
}Expand description
One cumulative commit in a study block.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.label: Option<String>created_at: Option<String>edits: Vec<StudyEdit>metadata: BTreeMap<String, Value>Trait Implementations
Sourceimpl Clone for StudyCommit
impl Clone for StudyCommit
Sourcefn clone(&self) -> StudyCommit
fn clone(&self) -> StudyCommit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StudyCommit
impl Debug for StudyCommit
Sourceimpl Default for StudyCommit
impl Default for StudyCommit
Sourcefn default() -> StudyCommit
fn default() -> StudyCommit
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StudyCommit
impl<'de> Deserialize<'de> for StudyCommit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StudyCommit
impl JsonSchema for StudyCommit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StudyCommit
impl PartialEq for StudyCommit
Sourceimpl Serialize for StudyCommit
impl Serialize for StudyCommit
impl StructuralPartialEq for StudyCommit