pub struct ObjectUnits {
pub power: Option<String>,
pub angle: Option<String>,
pub base_mva: Option<f64>,
}Fields
power: Option<String>angle: Option<String>base_mva: Option<f64>Trait Implementations
Sourceimpl Clone for ObjectUnits
impl Clone for ObjectUnits
Sourcefn clone(&self) -> ObjectUnits
fn clone(&self) -> ObjectUnits
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObjectUnits
impl Debug for ObjectUnits
Sourceimpl Default for ObjectUnits
impl Default for ObjectUnits
Sourcefn default() -> ObjectUnits
fn default() -> ObjectUnits
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ObjectUnits
impl<'de> Deserialize<'de> for ObjectUnits
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ObjectUnits
impl JsonSchema for ObjectUnits
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ObjectUnits
impl PartialEq for ObjectUnits
Sourceimpl Serialize for ObjectUnits
impl Serialize for ObjectUnits
impl StructuralPartialEq for ObjectUnits