pub struct ValidationCounts {
pub fatal: u32,
pub error: u32,
pub warning: u32,
pub info: u32,
pub debug: u32,
}Expand description
Counts per severity. All five are always present; zero where unused.
Fields
fatal: u32error: u32warning: u32info: u32debug: u32Trait Implementations
Sourceimpl Clone for ValidationCounts
impl Clone for ValidationCounts
Sourcefn clone(&self) -> ValidationCounts
fn clone(&self) -> ValidationCounts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ValidationCounts
Sourceimpl Debug for ValidationCounts
impl Debug for ValidationCounts
Sourceimpl Default for ValidationCounts
impl Default for ValidationCounts
Sourcefn default() -> ValidationCounts
fn default() -> ValidationCounts
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ValidationCounts
impl<'de> Deserialize<'de> for ValidationCounts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ValidationCounts
Sourceimpl JsonSchema for ValidationCounts
impl JsonSchema for ValidationCounts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ValidationCounts
impl PartialEq for ValidationCounts
Sourceimpl Serialize for ValidationCounts
impl Serialize for ValidationCounts
impl StructuralPartialEq for ValidationCounts